@@ -1,18 +1,15 @@
 import pandas as pd
-import csv
 import glob
 from pathlib import Path
 
 
 def concat_rois(directory, output_dir, trial_type):
 
-    if output_dir.endswith('/') == False:
+    if output_dir.endswith('/') is False:
 
         raise ValueError(
             'Output directory does not end with a trailing slash "/"!')
-
-    else:
-        pass
+    pass
 
     files = glob.glob(directory + '/*.csv')
 
